@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -84,7 +84,6 @@ private:
     void loadGlobalAutoCorrectionAndException();
     void setLanguage(const QString &lang);
 
-    AutoCorrectionWidgetPrivate *const d;
+    std::unique_ptr<AutoCorrectionWidgetPrivate> const d;
 };
 }
-
