@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SUBJECTLINEEDITWITHAUTOCORRECTION_H
-#define SUBJECTLINEEDITWITHAUTOCORRECTION_H
+#pragma once
 
 #include "pimcommon_export.h"
 
@@ -35,8 +34,6 @@ protected:
     void keyPressEvent(QKeyEvent *e) override;
 
 private:
-    LineEditWithAutoCorrectionPrivate *const d;
+    std::unique_ptr<LineEditWithAutoCorrectionPrivate> const d;
 };
 }
-
-#endif // SUBJECTLINEEDITWITHAUTOCORRECTION_H
